/* SPDX-License-Identifier: GPL-2.0
 * Copyright 2021 NXP
 */

#ifndef _NET_DSA_TAG_MV88E6XXX_H
#define _NET_DSA_TAG_MV88E6XXX_H

#include <linux/if_vlan.h>

#define MV88E6XXX_VID_STANDALONE	0
#define MV88E6XXX_VID_BRIDGED		(VLAN_N_VID - 1)

#endif
