/* auto-generated by scripts/xen-hypercall.sh */
HYPERCALL(arch_1)
HYPERCALL(arch_2)
HYPERCALL(arch_3)
HYPERCALL(arch_4)
HYPERCALL(arch_5)
HYPERCALL(arch_6)
HYPERCALL(arch_7)
HYPERCALL(callback_op)
HYPERCALL(console_io)
HYPERCALL(dm_op)
HYPERCALL(domctl)
HYPERCALL(event_channel_op)
HYPERCALL(event_channel_op_compat)
HYPERCALL(fpu_taskswitch)
HYPERCALL(get_debugreg)
HYPERCALL(grant_table_op)
HYPERCALL(hvm_op)
HYPERCALL(iret)
HYPERCALL(kexec_op)
HYPERCALL(mca)
HYPERCALL(memory_op)
HYPERCALL(mmu_update)
HYPERCALL(mmuext_op)
HYPERCALL(multicall)
HYPERCALL(nmi_op)
HYPERCALL(physdev_op)
HYPERCALL(physdev_op_compat)
HYPERCALL(platform_op)
HYPERCALL(sched_op)
HYPERCALL(sched_op_compat)
HYPERCALL(set_callbacks)
HYPERCALL(set_debugreg)
HYPERCALL(set_gdt)
HYPERCALL(set_segment_base)
HYPERCALL(set_timer_op)
HYPERCALL(set_trap_table)
HYPERCALL(stack_switch)
HYPERCALL(sysctl)
HYPERCALL(tmem_op)
HYPERCALL(update_descriptor)
HYPERCALL(update_va_mapping)
HYPERCALL(update_va_mapping_otherdomain)
HYPERCALL(vcpu_op)
HYPERCALL(vm_assist)
HYPERCALL(xc_reserved_op)
HYPERCALL(xen_version)
HYPERCALL(xenoprof_op)
HYPERCALL(xenpmu_op)
HYPERCALL(xsm_op)
