/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (c) 2018, The Linux Foundation. All rights reserved.
 */

#ifndef _DT_BINDINGS_QCOM_PHY_QUSB2_H_
#define _DT_BINDINGS_QCOM_PHY_QUSB2_H_

/* PHY HSTX TRIM bit values (24mA to 15mA) */
#define QUSB2_V2_HSTX_TRIM_24_0_MA		0x0
#define QUSB2_V2_HSTX_TRIM_23_4_MA		0x1
#define QUSB2_V2_HSTX_TRIM_22_8_MA		0x2
#define QUSB2_V2_HSTX_TRIM_22_2_MA		0x3
#define QUSB2_V2_HSTX_TRIM_21_6_MA		0x4
#define QUSB2_V2_HSTX_TRIM_21_0_MA		0x5
#define QUSB2_V2_HSTX_TRIM_20_4_MA		0x6
#define QUSB2_V2_HSTX_TRIM_19_8_MA		0x7
#define QUSB2_V2_HSTX_TRIM_19_2_MA		0x8
#define QUSB2_V2_HSTX_TRIM_18_6_MA		0x9
#define QUSB2_V2_HSTX_TRIM_18_0_MA		0xa
#define QUSB2_V2_HSTX_TRIM_17_4_MA		0xb
#define QUSB2_V2_HSTX_TRIM_16_8_MA		0xc
#define QUSB2_V2_HSTX_TRIM_16_2_MA		0xd
#define QUSB2_V2_HSTX_TRIM_15_6_MA		0xe
#define QUSB2_V2_HSTX_TRIM_15_0_MA		0xf

/* PHY PREEMPHASIS bit values */
#define QUSB2_V2_PREEMPHASIS_NONE		0
#define QUSB2_V2_PREEMPHASIS_5_PERCENT		1
#define QUSB2_V2_PREEMPHASIS_10_PERCENT		2
#define QUSB2_V2_PREEMPHASIS_15_PERCENT		3

/* PHY PREEMPHASIS-WIDTH bit values */
#define QUSB2_V2_PREEMPHASIS_WIDTH_FULL_BIT	0
#define QUSB2_V2_PREEMPHASIS_WIDTH_HALF_BIT	1

#endif
